aboutsummaryrefslogtreecommitdiffhomepage
path: root/tests/RecordTestUtils.h
diff options
context:
space:
mode:
authorGravatar halcanary <halcanary@google.com>2015-08-27 07:41:13 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-08-27 07:41:16 -0700
commit96fcdcc219d2a0d3579719b84b28bede76efba64 (patch)
tree0ec5ea0193d8292df8bf5ed9dd8498a5eb5763dd /tests/RecordTestUtils.h
parent435af2f736c85c3274a0c6760a3523810750d237 (diff)
Style Change: NULL->nullptr
Diffstat (limited to 'tests/RecordTestUtils.h')
-rw-r--r--tests/RecordTestUtils.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/RecordTestUtils.h b/tests/RecordTestUtils.h
index 8243089e5d..e4421fab52 100644
--- a/tests/RecordTestUtils.h
+++ b/tests/RecordTestUtils.h
@@ -11,10 +11,10 @@
#include "SkRecord.h"
#include "SkRecords.h"
// If the command we're reading is a U, set ptr to it, otherwise set it to NULL.
template <typename U>
struct ReadAs {
- ReadAs() : ptr(NULL), type(SkRecords::Type(~0)) {}
+ ReadAs() : ptr(nullptr), type(SkRecords::Type(~0)) {}
const U* ptr;
SkRecords::Type type;
@@ -11,10 +11,10 @@
#include "SkRecord.h"
#include "SkRecords.h"
-// If the command we're reading is a U, set ptr to it, otherwise set it to NULL.
+// If the command we're reading is a U, set ptr to it, otherwise set it to nullptr.
template <typename U>
struct ReadAs {